@@ -7,21 +7,20 @@
 #ifndef LANLINKPROVIDER_H
 #define LANLINKPROVIDER_H
 
-#include <QObject>
-#include <QTcpServer>
-#include <QSslSocket>
-#include <QUdpSocket>
-#include <QTimer>
 #include <QNetworkSession>
+#include <QObject>
+#include <QSslSocket>
+#include <QTcpServer>
+#include <QTimer>
+#include <QUdpSocket>
 
-#include "kdeconnectcore_export.h"
 #include "backends/linkprovider.h"
-#include "server.h"
+#include "kdeconnectcore_export.h"
 #include "landevicelink.h"
+#include "server.h"
 
 class LanPairingHandler;
-class KDECONNECTCORE_EXPORT LanLinkProvider
-    : public LinkProvider
+class KDECONNECTCORE_EXPORT LanLinkProvider : public LinkProvider
 {
     Q_OBJECT
 
@@ -31,22 +30,24 @@ public:
      * @param udpBroadcastPort Port which should be used for *sending* identity packets
      * @param udpListenPort Port which should be used for *receiving* identity packets
      */
-    LanLinkProvider(
-            bool testMode = false,
-            quint16 udpBroadcastPort = UDP_PORT,
-            quint16 udpListenPort = UDP_PORT
-            );
+    LanLinkProvider(bool testMode = false, quint16 udpBroadcastPort = UDP_PORT, quint16 udpListenPort = UDP_PORT);
     ~LanLinkProvider() override;
 
-    QString name() override { return QStringLiteral("LanLinkProvider"); }
-    int priority() override { return PRIORITY_HIGH; }
+    QString name() override
+    {
+        return QStringLiteral("LanLinkProvider");
+    }
+    int priority() override
+    {
+        return PRIORITY_HIGH;
+    }
 
-    void userRequestsPair(const QString& deviceId);
-    void userRequestsUnpair(const QString& deviceId);
-    void incomingPairPacket(DeviceLink* device, const NetworkPacket& np);
+    void userRequestsPair(const QString &deviceId);
+    void userRequestsUnpair(const QString &deviceId);
+    void incomingPairPacket(DeviceLink *device, const NetworkPacket &np);
 
-    static void configureSslSocket(QSslSocket* socket, const QString& deviceId, bool isDeviceTrusted);
-    static void configureSocket(QSslSocket* socket);
+    static void configureSslSocket(QSslSocket *socket, const QString &deviceId, bool isDeviceTrusted);
+    static void configureSocket(QSslSocket *socket);
 
     /**
      * This is the default UDP port both for broadcasting and receiving identity packets
@@ -67,33 +68,33 @@ private Q_SLOTS:
     void udpBroadcastReceived();
     void newConnection();
     void dataReceived();
-    void deviceLinkDestroyed(QObject* destroyedDeviceLink);
-    void sslErrors(const QList<QSslError>& errors);
+    void deviceLinkDestroyed(QObject *destroyedDeviceLink);
+    void sslErrors(const QList<QSslError> &errors);
     void broadcastToNetwork();
 
 private:
-    LanPairingHandler* createPairingHandler(DeviceLink* link);
+    LanPairingHandler *createPairingHandler(DeviceLink *link);
 
-    void onNetworkConfigurationChanged(const QNetworkConfiguration& config);
-    void addLink(const QString& deviceId, QSslSocket* socket, NetworkPacket* receivedPacket, LanDeviceLink::ConnectionStarted connectionOrigin);
+    void onNetworkConfigurationChanged(const QNetworkConfiguration &config);
+    void addLink(const QString &deviceId, QSslSocket *socket, NetworkPacket *receivedPacket, LanDeviceLink::ConnectionStarted connectionOrigin);
     QList<QHostAddress> getBroadcastAddresses();
-    void sendBroadcasts(QUdpSocket& socket, const NetworkPacket &np, const QList<QHostAddress>& addresses);
+    void sendBroadcasts(QUdpSocket &socket, const NetworkPacket &np, const QList<QHostAddress> &addresses);
 
-    Server* m_server;
+    Server *m_server;
     QUdpSocket m_udpSocket;
     quint16 m_tcpPort;
 
     quint16 m_udpBroadcastPort;
     quint16 m_udpListenPort;
 
-    QMap<QString, LanDeviceLink*> m_links;
-    QMap<QString, LanPairingHandler*> m_pairingHandlers;
+    QMap<QString, LanDeviceLink *> m_links;
+    QMap<QString, LanPairingHandler *> m_pairingHandlers;
 
     struct PendingConnect {
-        NetworkPacket* np;
+        NetworkPacket *np;
         QHostAddress sender;
     };
-    QMap<QSslSocket*, PendingConnect> m_receivedIdentityPackets;
+    QMap<QSslSocket *, PendingConnect> m_receivedIdentityPackets;
     QNetworkConfiguration m_lastConfig;
     const bool m_testMode;
     QTimer m_combineBroadcastsTimer;
