@@ -14,16 +14,14 @@
 
 class DeviceLink;
 
-class KDECONNECTCORE_EXPORT LinkProvider
-    : public QObject
+class KDECONNECTCORE_EXPORT LinkProvider : public QObject
 {
     Q_OBJECT
 
 public:
-
-    const static int PRIORITY_LOW = 0;      //eg: 3g internet
-    const static int PRIORITY_MEDIUM = 50;  //eg: internet
-    const static int PRIORITY_HIGH = 100;   //eg: lan
+    const static int PRIORITY_LOW = 0; // eg: 3g internet
+    const static int PRIORITY_MEDIUM = 50; // eg: internet
+    const static int PRIORITY_HIGH = 100; // eg: lan
 
     LinkProvider();
     ~LinkProvider() override = default;
@@ -39,11 +37,10 @@ public Q_SLOTS:
     void suspend(bool suspend);
 
 Q_SIGNALS:
-    //NOTE: The provider will destroy the DeviceLink when it's no longer accessible,
-    //      and every user should listen to the destroyed signal to remove its references.
-    //      That's the reason because there is no "onConnectionLost".
-    void onConnectionReceived(const NetworkPacket& identityPacket, DeviceLink*);
-
+    // NOTE: The provider will destroy the DeviceLink when it's no longer accessible,
+    //       and every user should listen to the destroyed signal to remove its references.
+    //       That's the reason because there is no "onConnectionLost".
+    void onConnectionReceived(const NetworkPacket &identityPacket, DeviceLink *);
 };
 
 #endif
