@@ -5,23 +5,23 @@
  */
 
 #include "compositefiletransferjob.h"
-#include <core_debug.h>
-#include <KLocalizedString>
-#include <KJobTrackerInterface>
-#include <daemon.h>
 #include "filetransferjob.h"
+#include <KJobTrackerInterface>
+#include <KLocalizedString>
+#include <core_debug.h>
+#include <daemon.h>
 
-CompositeFileTransferJob::CompositeFileTransferJob(const QString& deviceId)
+CompositeFileTransferJob::CompositeFileTransferJob(const QString &deviceId)
     : KCompositeJob()
     , m_deviceId(deviceId)
     , m_running(false)
     , m_currentJobNum(1)
     , m_totalJobs(0)
-    , m_currentJobSendPayloadSize(0)
-    , m_totalSendPayloadSize(0)
+    , m_currentJobSentPayloadSize(0)
+    , m_totalSentPayloadSize(0)
+    , m_oldTotalSentPayloadSize(0)
     , m_totalPayloadSize(0)
     , m_currentJob(nullptr)
-    , m_prevElapsedTime(0)
 {
     setCapabilities(Killable);
 }
@@ -39,22 +39,29 @@ void CompositeFileTransferJob::start()
 
 void CompositeFileTransferJob::startNextSubJob()
 {
-    m_currentJob = qobject_cast<FileTransferJob*>(subjobs().at(0));
-    m_currentJobSendPayloadSize = 0;
-    emitDescription(m_currentJob->destination().toString());
+    m_currentJob = qobject_cast<FileTransferJob *>(subjobs().at(0));
+    m_currentJobSentPayloadSize = 0;
+
+    Q_EMIT description(this,
+                       i18ncp("@title job", "Receiving file", "Receiving files", m_totalJobs),
+                       {i18nc("The source of a file operation", "Source"), Daemon::instance()->getDevice(this->m_deviceId)->name()},
+                       {i18nc("The destination of a file operation", "Destination"), m_currentJob->destination().toDisplayString(QUrl::PreferLocalFile)});
+
     m_currentJob->start();
 #ifdef SAILFISHOS
-    connect(m_currentJob, SIGNAL(processedAmount(KJob*,KJob::Unit,qulonglong)), this, SLOT(slotProcessedAmount(KJob*,KJob::Unit,qulonglong)));
+    connect(m_currentJob, SIGNAL(processedAmount(KJob *, KJob::Unit, qulonglong)), this, SLOT(slotProcessedAmount(KJob *, KJob::Unit, qulonglong)));
 #else
-    connect(m_currentJob, QOverload<KJob*,KJob::Unit,qulonglong>::of(&FileTransferJob::processedAmount), this, &CompositeFileTransferJob::slotProcessedAmount);
+    connect(m_currentJob,
+            QOverload<KJob *, KJob::Unit, qulonglong>::of(&FileTransferJob::processedAmount),
+            this,
+            &CompositeFileTransferJob::slotProcessedAmount);
 #endif
 }
 
-bool CompositeFileTransferJob::addSubjob(KJob* job)
+bool CompositeFileTransferJob::addSubjob(KJob *job)
 {
-    if (FileTransferJob *uploadJob = qobject_cast<FileTransferJob*>(job)) {
-
-        const NetworkPacket* np = uploadJob->networkPacket();
+    if (FileTransferJob *uploadJob = qobject_cast<FileTransferJob *>(job)) {
+        const NetworkPacket *np = uploadJob->networkPacket();
 
         if (np->has(QStringLiteral("totalPayloadSize"))) {
             m_totalPayloadSize = np->get<quint64>(QStringLiteral("totalPayloadSize"));
@@ -66,9 +73,6 @@ bool CompositeFileTransferJob::addSubjob(KJob* job)
             setTotalAmount(Files, m_totalJobs);
         }
 
-        QString filename = np->get<QString>(QStringLiteral("filename"));
-        emitDescription(filename);
-
         if (!hasSubjobs()) {
             QMetaObject::invokeMethod(this, "startNextSubJob", Qt::QueuedConnection);
         }
@@ -93,31 +97,40 @@ bool CompositeFileTransferJob::doKill()
 void CompositeFileTransferJob::slotProcessedAmount(KJob *job, KJob::Unit unit, qulonglong amount)
 {
     Q_UNUSED(job);
-    m_currentJobSendPayloadSize = amount;
-    quint64 uploaded = m_totalSendPayloadSize + m_currentJobSendPayloadSize;
 
-    if (uploaded == m_totalPayloadSize || m_prevElapsedTime == 0 || m_timer.elapsed() - m_prevElapsedTime >= 100) {
-        m_prevElapsedTime = m_timer.elapsed();
-        setProcessedAmount(unit, uploaded);
+    m_currentJobSentPayloadSize = amount;
+    const auto totalSent = m_totalSentPayloadSize + m_currentJobSentPayloadSize;
 
-        const auto elapsed = m_timer.elapsed();
-        if (elapsed > 0) {
-            emitSpeed((1000 * uploaded) / elapsed);
-        }
+    if (!m_reportTimer.isValid()) {
+        m_reportTimer.start();
+    }
+    if (m_reportTimer.hasExpired(250)) {
+        setProcessedAmount(unit, totalSent);
+        m_reportTimer.restart();
+    }
+
+    if (!m_speedTimer.isValid()) {
+        m_speedTimer.start();
+    }
+    if (m_speedTimer.hasExpired(1000)) {
+        emitSpeed(1000 * (totalSent - m_oldTotalSentPayloadSize) / m_speedTimer.elapsed());
+        m_oldTotalSentPayloadSize = totalSent;
+        m_speedTimer.restart();
     }
 }
 
 void CompositeFileTransferJob::slotResult(KJob *job)
 {
-    //Copies job error and errorText and emits result if job is in error otherwise removes job from subjob list
+    // Copies job error and errorText and emits result if job is in error otherwise removes job from subjob list
     KCompositeJob::slotResult(job);
 
     if (error() || !m_running) {
         return;
     }
 
-    m_totalSendPayloadSize += m_currentJobSendPayloadSize;
+    m_totalSentPayloadSize += m_currentJobSentPayloadSize;
 
+    setProcessedAmount(Bytes, m_totalSentPayloadSize);
     setProcessedAmount(Files, m_currentJobNum);
 
     if (m_currentJobNum < m_totalJobs) {
@@ -129,21 +142,3 @@ void CompositeFileTransferJob::slotResult(KJob *job)
         emitResult();
     }
 }
-
-void CompositeFileTransferJob::emitDescription(const QString& currentFileName)
-{
-    QPair<QString, QString> field2;
-
-    const QUrl fileUrl(currentFileName);
-    const QString fileName = fileUrl.toDisplayString(QUrl::PreferLocalFile);
-
-    if (m_totalJobs > 1) {
-        field2.first = i18n("Progress");
-        field2.second = i18n("Receiving file %1 of %2", m_currentJobNum, m_totalJobs);
-    }
-
-    Q_EMIT description(this, i18np("Receiving file from %2", "Receiving %1 files from %2", m_totalJobs, Daemon::instance()->getDevice(this->m_deviceId)->name()),
-                       { i18n("File"), fileName }, field2
-    );
-}
-
