@@ -18,16 +18,25 @@
 
 #ifdef Q_OS_WIN
 #include <QUrl>
-    namespace processes {
-            const QString dbus_daemon = QStringLiteral("dbus-daemon.exe");
-            const QString kdeconnect_daemon = QStringLiteral("kdeconnectd.exe");
-    };
+namespace processes
+{
+const QString dbus_daemon = QStringLiteral("dbus-daemon.exe");
+const QString kdeconnect_daemon = QStringLiteral("kdeconnectd.exe");
+const QString kdeconnect_app = QStringLiteral("kdeconnect-app.exe");
+const QString kdeconnect_handler = QStringLiteral("kdeconnect-handler.exe");
+const QString kdeconnect_settings = QStringLiteral("kdeconnect-settings.exe");
+const QString kdeconnect_sms = QStringLiteral("kdeconnect-sms.exe");
+};
 #endif
 
 class IndicatorHelper
 {
 public:
+#ifdef Q_OS_WIN
+    IndicatorHelper(const QUrl &indicatorUrl);
+#else
     IndicatorHelper();
+#endif
     ~IndicatorHelper();
 
     void preInit();
@@ -43,6 +52,11 @@ public:
     void systrayIconHook(KStatusNotifierItem &systray);
 #endif
 
+private:
+#ifdef Q_OS_MAC
+    QSplashScreen *m_splashScreen;
+#endif
+
 #ifdef Q_OS_WIN
     /**
      * Terminate processes of KDE Connect like kdeconnectd.exe and dbus-daemon.exe
@@ -51,11 +65,7 @@ public:
      */
 
     bool terminateProcess(const QString &processName, const QUrl &indicatorUrl) const;
-#endif
-
-private:
-#ifdef Q_OS_MAC
-    QSplashScreen *m_splashScreen;
+    QUrl m_indicatorUrl;
 #endif
 };
 
