@@ -7,11 +7,14 @@
 #ifndef CLIPBOARDLISTENER_H
 #define CLIPBOARDLISTENER_H
 
-#include <QDateTime>
-#include <QTimer>
-#include <QObject>
 #include <QClipboard>
-#include <QGuiApplication>
+#include <QObject>
+
+#ifdef Q_OS_MAC
+#include <QTimer>
+#endif
+
+class KSystemClipboard;
 
 /**
  * Wrapper around QClipboard, which emits clipboardChanged only when it really changed
@@ -21,54 +24,37 @@ class ClipboardListener : public QObject
 {
     Q_OBJECT
 
+public:
+    enum ClipboardContentType { ClipboardContentTypeUnknown = 0, ClipboardContentTypePassword = 1 };
+
 protected:
     ClipboardListener();
-    void refreshContent(const QString &content);
+    void refreshContent(const QString &content, ClipboardContentType contentType);
     QString m_currentContent;
+    ClipboardContentType m_currentContentType;
 
 private:
     qint64 m_updateTimestamp = 0;
 
 public:
-    static ClipboardListener* instance();
+    static ClipboardListener *instance();
 
-    virtual void setText(const QString& content) = 0;
+    void setText(const QString &content);
 
     QString currentContent();
+    ClipboardContentType currentContentType();
     qint64 updateTimestamp();
 
 Q_SIGNALS:
-    void clipboardChanged(const QString& content);
-};
-
-class QClipboardListener : public ClipboardListener
-{
-public:
-    QClipboardListener();
-
-    void setText(const QString & content) override;
+    void clipboardChanged(const QString &content, ClipboardContentType contentType);
 
 private:
+    void updateClipboard(QClipboard::Mode mode);
+
 #ifdef Q_OS_MAC
     QTimer m_clipboardMonitorTimer;
 #endif
-    void updateClipboard(QClipboard::Mode mode);
-    QClipboard* clipboard;
-};
-
-class DataControl;
-
-class WaylandClipboardListener : public ClipboardListener
-{
-public:
-    WaylandClipboardListener();
-
-    void setText(const QString & content) override;
-
-private:
-    void refresh();
-
-    DataControl *m_dataControl;
+    KSystemClipboard *clipboard;
 };
 
 #endif
