@@ -7,10 +7,12 @@
 #ifndef CLIPBOARDPLUGIN_H
 #define CLIPBOARDPLUGIN_H
 
-#include <QObject>
 #include <QClipboard>
+#include <QObject>
 #include <core/kdeconnectplugin.h>
 
+#include "clipboardlistener.h"
+
 /**
  * Packet containing just clipboard contents, sent when a device updates its clipboard.
  * <p>
@@ -36,20 +38,18 @@
  */
 #define PACKET_TYPE_CLIPBOARD_CONNECT QStringLiteral("kdeconnect.clipboard.connect")
 
-class ClipboardPlugin
-    : public KdeConnectPlugin
+class ClipboardPlugin : public KdeConnectPlugin
 {
     Q_OBJECT
 
 public:
-    explicit ClipboardPlugin(QObject* parent, const QVariantList& args);
+    explicit ClipboardPlugin(QObject *parent, const QVariantList &args);
 
-    bool receivePacket(const NetworkPacket& np) override;
+    bool receivePacket(const NetworkPacket &np) override;
     void connected() override;
 private Q_SLOTS:
-    void propagateClipboard(const QString& content);
+    void propagateClipboard(const QString &content, ClipboardListener::ClipboardContentType contentType);
     void sendConnectPacket();
-
 };
 
 #endif
