@@ -7,31 +7,24 @@
 #ifndef WAYLANDREMOTEINPUT_H
 #define WAYLANDREMOTEINPUT_H
 
-#include <QPointer>
 #include "abstractremoteinput.h"
 
-namespace KWayland
-{
-    namespace Client
-    {
-        class FakeInput;
-    }
-}
+class FakeInput;
 
-class WaylandRemoteInput
-    : public AbstractRemoteInput
+class WaylandRemoteInput : public AbstractRemoteInput
 {
     Q_OBJECT
 
 public:
-    explicit WaylandRemoteInput(QObject* parent);
+    explicit WaylandRemoteInput(QObject *parent);
+    ~WaylandRemoteInput();
 
-    bool handlePacket(const NetworkPacket& np) override;
+    bool handlePacket(const NetworkPacket &np) override;
 
 private:
     void setupWaylandIntegration();
 
-    QPointer<KWayland::Client::FakeInput> m_waylandInput;
+    FakeInput *m_fakeInput;
     bool m_waylandAuthenticationRequested;
 };
 
