@@ -7,34 +7,38 @@
 #include "notification.h"
 #include "plugin_notification_debug.h"
 
+#include "knotifications_version.h"
 #include <KNotification>
-#include <QtGlobal>
-#include <QIcon>
-#include <QString>
-#include <QUrl>
-#include <QPixmap>
+#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+#include <KNotificationReplyAction>
+#endif
 #include <KLocalizedString>
 #include <QFile>
-#include <knotifications_version.h>
+#include <QIcon>
 #include <QJsonArray>
+#include <QPixmap>
+#include <QString>
+#include <QUrl>
+#include <QtGlobal>
+#include <knotifications_version.h>
 
 #include <core/filetransferjob.h>
 #include <core/notificationserverinfo.h>
 
-QMap<QString, FileTransferJob*> Notification::s_downloadsInProgress;
+QMap<QString, FileTransferJob *> Notification::s_downloadsInProgress;
 
-Notification::Notification(const NetworkPacket& np, const Device* device, QObject* parent)
+Notification::Notification(const NetworkPacket &np, const Device *device, QObject *parent)
     : QObject(parent)
     , m_imagesDir()
     , m_device(device)
 {
-    //Make a own directory for each user so no one can see each others icons
+    // Make a own directory for each user so no one can see each others icons
     QString username;
-    #ifdef Q_OS_WIN
-        username = QString::fromLatin1(qgetenv("USERNAME"));
-    #else
-        username = QString::fromLatin1(qgetenv("USER"));
-    #endif
+#ifdef Q_OS_WIN
+    username = QString::fromLatin1(qgetenv("USERNAME"));
+#else
+    username = QString::fromLatin1(qgetenv("USER"));
+#endif
 
     m_imagesDir.setPath(QDir::temp().absoluteFilePath(QStringLiteral("kdeconnect_") + username));
     m_imagesDir.mkpath(m_imagesDir.absolutePath());
@@ -44,11 +48,14 @@ Notification::Notification(const NetworkPacket& np, const Device* device, QObjec
     parseNetworkPacket(np);
     createKNotification(np);
 
-    connect(m_notification, QOverload<unsigned int>::of(&KNotification::activated), this, [this] (unsigned int actionIndex) {
+    connect(m_notification, QOverload<unsigned int>::of(&KNotification::activated), this, [this](unsigned int actionIndex) {
+// Since 5.81 we use KNotification's inline reply instead of our own action
+#if KNOTIFICATIONS_VERSION < QT_VERSION_CHECK(5, 81, 0)
         // Do nothing for our own reply action
-        if(!m_requestReplyId.isEmpty() && actionIndex == 1) {
+        if (!m_requestReplyId.isEmpty() && actionIndex == 1) {
             return;
         }
+#endif
         // Notification action indices start at 1
         Q_EMIT actionTriggered(m_internalId, m_actions[actionIndex - 1]);
     });
@@ -74,17 +81,19 @@ void Notification::show()
     }
 }
 
-void Notification::update(const NetworkPacket& np)
+void Notification::update(const NetworkPacket &np)
 {
     parseNetworkPacket(np);
     createKNotification(np);
 }
 
-void Notification::createKNotification(const NetworkPacket& np)
+void Notification::createKNotification(const NetworkPacket &np)
 {
     if (!m_notification) {
         m_notification = new KNotification(QStringLiteral("notification"), KNotification::CloseOnTimeout, this);
         m_notification->setComponentName(QStringLiteral("kdeconnect"));
+        m_notification->setHint(QStringLiteral("resident"),
+                                true); // This means the notification won't be deleted automatically, but only with KNotifications 5.81
     }
 
     QString escapedTitle = m_title.toHtmlEscaped();
@@ -115,8 +124,17 @@ void Notification::createKNotification(const NetworkPacket& np)
     m_notification->setHint(QStringLiteral("x-kde-origin-name"), m_device->name());
 
     if (!m_requestReplyId.isEmpty()) {
+#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+        auto replyAction = std::make_unique<KNotificationReplyAction>(i18nc("@action:button", "Reply"));
+        replyAction->setPlaceholderText(i18nc("@info:placeholder", "Reply to %1...", m_appName));
+        replyAction->setFallbackBehavior(KNotificationReplyAction::FallbackBehavior::UseRegularAction);
+        QObject::connect(replyAction.get(), &KNotificationReplyAction::replied, this, &Notification::replied);
+        QObject::connect(replyAction.get(), &KNotificationReplyAction::activated, this, &Notification::reply);
+        m_notification->setReplyAction(std::move(replyAction));
+#else
         m_actions.prepend(i18n("Reply"));
         connect(m_notification, &KNotification::action1Activated, this, &Notification::reply, Qt::UniqueConnection);
+#endif
     }
 
     m_notification->setActions(m_actions);
@@ -131,7 +149,7 @@ void Notification::createKNotification(const NetworkPacket& np)
     }
 }
 
-void Notification::loadIcon(const NetworkPacket& np)
+void Notification::loadIcon(const NetworkPacket &np)
 {
     m_ready = false;
 
@@ -139,14 +157,14 @@ void Notification::loadIcon(const NetworkPacket& np)
         applyIcon();
         show();
     } else {
-        FileTransferJob* fileTransferJob = s_downloadsInProgress.value(m_iconPath);
+        FileTransferJob *fileTransferJob = s_downloadsInProgress.value(m_iconPath);
         if (!fileTransferJob) {
             fileTransferJob = np.createPayloadTransferJob(QUrl::fromLocalFile(m_iconPath));
             fileTransferJob->start();
             s_downloadsInProgress[m_iconPath] = fileTransferJob;
         }
 
-        connect(fileTransferJob, &FileTransferJob::result, this, [this, fileTransferJob]{
+        connect(fileTransferJob, &FileTransferJob::result, this, [this, fileTransferJob] {
             s_downloadsInProgress.remove(m_iconPath);
             if (fileTransferJob->error()) {
                 qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Error in FileTransferJob: " << fileTransferJob->errorString();
@@ -169,6 +187,11 @@ void Notification::reply()
     Q_EMIT replyRequested();
 }
 
+void Notification::sendReply(const QString& message)
+{
+    Q_EMIT replied(message);
+}
+
 void Notification::parseNetworkPacket(const NetworkPacket& np)
 {
     m_internalId = np.get<QString>(QStringLiteral("id"));
@@ -185,8 +208,7 @@ void Notification::parseNetworkPacket(const NetworkPacket& np)
     m_actions.clear();
 
     const auto actions = np.get<QJsonArray>(QStringLiteral("actions"));
-    for (const QJsonValue& value : actions) {
+    for (const QJsonValue &value : actions) {
         m_actions.append(value.toString());
     }
-
 }
