@@ -6,18 +6,19 @@
 
 #include "screensaverinhibitplugin-macos.h"
 
-#include <KPluginFactory>
 #include "kdeconnect_screensaverinhibit_debug.h"
+#include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(ScreensaverInhibitPlugin, "kdeconnect_screensaver_inhibit.json")
 
-ScreensaverInhibitPlugin::ScreensaverInhibitPlugin(QObject* parent, const QVariantList& args)
-    : KdeConnectPlugin(parent, args), m_caffeinateProcess(nullptr)
+ScreensaverInhibitPlugin::ScreensaverInhibitPlugin(QObject *parent, const QVariantList &args)
+    : KdeConnectPlugin(parent, args)
+    , m_caffeinateProcess(nullptr)
 {
     if (QFile::exists(QStringLiteral("/usr/bin/caffeinate"))) {
         m_caffeinateProcess = new QProcess();
         m_caffeinateProcess->setProgram(QStringLiteral("caffeinate"));
-        m_caffeinateProcess->setArguments({QStringLiteral("-d")});      // Prevent the display from sleeping
+        m_caffeinateProcess->setArguments({QStringLiteral("-d")}); // Prevent the display from sleeping
         m_caffeinateProcess->start();
     } else {
         qWarning(KDECONNECT_PLUGIN_SCREENSAVERINHIBIT) << "Cannot find caffeinate on macOS install";
@@ -36,7 +37,7 @@ void ScreensaverInhibitPlugin::connected()
 {
 }
 
-bool ScreensaverInhibitPlugin::receivePacket(const NetworkPacket& np)
+bool ScreensaverInhibitPlugin::receivePacket(const NetworkPacket &np)
 {
     Q_UNUSED(np);
     return false;
