@@ -6,18 +6,21 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QStyle>
 #include <QStandardPaths>
+#include <QStyle>
 
-#include <KCMultiDialog>
-#include <KAboutData>
-#include <KLocalizedString>
-#include <KDBusService>
 #include "kdeconnect-version.h"
+#include <KAboutData>
+#include <KCMultiDialog>
+#include <KDBusService>
+#include <KLocalizedString>
+#include <KWindowSystem>
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
@@ -38,20 +41,25 @@ int main(int argc, char** argv)
 
     KDBusService dbusService(KDBusService::Unique);
 
-    KCMultiDialog* dialog = new KCMultiDialog;
-    dialog->addModule(QStringLiteral("kcm_kdeconnect"), {parser.value(QStringLiteral("args"))});
-
-    auto style = dialog->style();
-    dialog->setContentsMargins(style->pixelMetric(QStyle::PM_LayoutLeftMargin),
-                               style->pixelMetric(QStyle::PM_LayoutTopMargin),
-                               style->pixelMetric(QStyle::PM_LayoutRightMargin),
-                               style->pixelMetric(QStyle::PM_LayoutBottomMargin));
+    KCMultiDialog *dialog = new KCMultiDialog;
+    dialog->addModule(KPluginMetaData(QStringLiteral("kcm_kdeconnect")), {parser.value(QStringLiteral("args"))});
 
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->show();
 
+    QObject::connect(&dbusService, &KDBusService::activateRequested, dialog, [dialog](const QStringList &args, const QString & /*workingDir*/) {
+        KWindowSystem::updateStartupId(dialog->windowHandle());
+        KWindowSystem::activateWindow(dialog->windowHandle());
+
+        QCommandLineParser parser;
+        parser.addOption(QCommandLineOption(QStringLiteral("args"), i18n("Arguments for the config module"), QStringLiteral("args")));
+        parser.parse(args);
+
+        dialog->clear();
+        dialog->addModule(KPluginMetaData(QStringLiteral("kcm_kdeconnect")), {parser.value(QStringLiteral("args"))});
+    });
+
     app.setQuitOnLastWindowClosed(true);
 
     return app.exec();
 }
-
